@@ -226,6 +226,7 @@ class MultipleSegmentBase(SegmentBase):
 
         self.duration = None                                  # xs:unsignedInt
         self.start_number = None                              # xs:unsignedInt
+        self.end_number = None                                # xs:unsignedInt
 
         self.segment_timelines = None                         # SegmentTimelineType*
         self.bitstream_switchings = None                      # URLType*
@@ -235,6 +236,7 @@ class MultipleSegmentBase(SegmentBase):
 
         self.duration = parse_attr_value(xmlnode, 'duration', int)
         self.start_number = parse_attr_value(xmlnode, 'startNumber', int)
+        self.end_number = parse_attr_value(xmlnode, 'endNumber', int)
 
         self.segment_timelines = parse_child_nodes(xmlnode, 'SegmentTimeline', SegmentTimeline)
         self.bitstream_switchings = parse_child_nodes(xmlnode, 'BitstreamSwitching', URL)
@@ -244,6 +246,7 @@ class MultipleSegmentBase(SegmentBase):
 
         write_attr_value(xmlnode, 'duration', self.duration)
         write_attr_value(xmlnode, 'startNumber', self.start_number)
+        write_attr_value(xmlnode, 'endNumber', self.end_number)
 
         write_child_node(xmlnode, 'SegmentTimeline', self.segment_timelines)
         write_child_node(xmlnode, 'BitstreamSwitching', self.bitstream_switchings)
@@ -332,6 +335,46 @@ class Descriptor(XMLNode):
         write_attr_value(xmlnode, 'id', self.id)
 
 
+class PSSH(XMLNode):
+    def __init__(self):
+        self.pssh = None
+
+    def parse(self, xmlnode):
+        self.pssh = parse_node_value(xmlnode, str)
+
+    def write(self, xmlnode):
+        write_node_value(xmlnode, self.pssh)
+
+
+class ContentProtection(XMLNode):
+    def __init__(self):
+        self.scheme_id_uri = ""                            # xs:anyURI (required)
+        self.value = None                                  # xs:string
+        self.id = None                                     # xs:string
+        self.pssh = None                                   # PSSH
+        self.default_key_id = None                         # xs:string
+        self.ns2_key_id = None                             # xs:string
+        self.cenc_default_kid = None                       # xs:string
+
+    def parse(self, xmlnode):
+        self.scheme_id_uri = parse_attr_value(xmlnode, "schemeIdUri", str)
+        self.value = parse_attr_value(xmlnode, "value", str)
+        self.id = parse_attr_value(xmlnode, "id", str)
+        self.default_key_id = parse_attr_value(xmlnode, "default_KID", str)
+        self.ns2_key_id = parse_attr_value(xmlnode, "ns2:default_KID", str)
+        self.cenc_default_kid = parse_attr_value(xmlnode, "cenc:default_KID", str)
+        self.pssh = parse_child_nodes(xmlnode, "cenc:pssh", PSSH)
+
+    def write(self, xmlnode):
+        write_attr_value(xmlnode, "schemeIdUri", self.scheme_id_uri)
+        write_attr_value(xmlnode, "value", self.value)
+        write_attr_value(xmlnode, "id", self.id)
+        write_attr_value(xmlnode, "default_KID", self.default_key_id)
+        write_attr_value(xmlnode, "ns2:default_KID", self.ns2_key_id)
+        write_attr_value(xmlnode, "cenc:default_KID", self.cenc_default_kid)
+        write_child_node(xmlnode, "cenc:pssh", self.pssh)
+
+
 class ContentComponent(XMLNode):
     def __init__(self):
         self.id = None                                        # xs:unsigendInt
@@ -369,6 +412,7 @@ class ContentComponent(XMLNode):
 
 class RepresentationBase(XMLNode):
     def __init__(self):
+        self.profile = None                                   # xs:string
         self.profiles = None                                  # xs:string
         self.width = None                                     # xs:unsigendInt
         self.height = None                                    # xs:unsigendInt
@@ -386,13 +430,14 @@ class RepresentationBase(XMLNode):
 
         self.frame_packings = None                            # DescriptorType*
         self.audio_channel_configurations = None              # DescriptorType*
-        self.content_protections = None                       # DescriptorType*
+        self.content_protections = None                       # ContentProtection*
         self.essential_properties = None                      # DescriptorType*
         self.supplemental_properties = None                   # DescriptorType*
         self.inband_event_streams = None                      # DescriptorType*
 
     def parse(self, xmlnode):
-        self.profiles = parse_attr_value(xmlnode, 'profile', str)
+        self.profile = parse_attr_value(xmlnode, 'profile', str)
+        self.profiles = parse_attr_value(xmlnode, 'profiles', str)
         self.width = parse_attr_value(xmlnode, 'width', int)
         self.height = parse_attr_value(xmlnode, 'height', int)
         self.sar = parse_attr_value(xmlnode, 'sar', str)
@@ -409,13 +454,14 @@ class RepresentationBase(XMLNode):
 
         self.frame_packings = parse_child_nodes(xmlnode, 'FramePacking', Descriptor)
         self.audio_channel_configurations = parse_child_nodes(xmlnode, 'AudioChannelConfiguration', Descriptor)
-        self.content_protections = parse_child_nodes(xmlnode, 'ContentProtection', Descriptor)
+        self.content_protections = parse_child_nodes(xmlnode, 'ContentProtection', ContentProtection)
         self.essential_properties = parse_child_nodes(xmlnode, 'EssentialProperty', Descriptor)
         self.supplemental_properties = parse_child_nodes(xmlnode, 'SupplementalProperty', Descriptor)
         self.inband_event_streams = parse_child_nodes(xmlnode, 'InbandEventStream', Descriptor)
 
     def write(self, xmlnode):
-        write_attr_value(xmlnode, 'profile', self.profiles)
+        write_attr_value(xmlnode, 'profile', self.profile)
+        write_attr_value(xmlnode, 'profiles', self.profiles)
         write_attr_value(xmlnode, 'width', self.width)
         write_attr_value(xmlnode, 'height', self.height)
         write_attr_value(xmlnode, 'sar', self.sar)
@@ -521,6 +567,7 @@ class AdaptationSet(RepresentationBase):
         self.id = None                                        # xs:unsignedInt
         self.group = None                                     # xs:unsignedInt
         self.lang = None                                      # xs:language
+        self.label = None                                     # xs:string
         self.content_type = None                              # xs:string
         self.par = None                                       # RatioType
         self.min_bandwidth = None                             # xs:unsignedInt
@@ -532,6 +579,7 @@ class AdaptationSet(RepresentationBase):
         self.min_frame_rate = None                            # FrameRateType
         self.max_frame_rate = None                            # FrameRateType
         self.segment_alignment = None                         # ConditionalUintType
+        self.selection_priority = None                        # xs:unsignedInt
         self.subsegment_alignment = None                      # ConditionalUintType
         self.subsegment_starts_with_sap = None                # SAPType
         self.bitstream_switching = None                       # xs:boolean
@@ -553,6 +601,7 @@ class AdaptationSet(RepresentationBase):
         self.id = parse_attr_value(xmlnode, 'id', int)
         self.group = parse_attr_value(xmlnode, 'group', int)
         self.lang = parse_attr_value(xmlnode, 'lang', str)
+        self.label = parse_attr_value(xmlnode, 'label', str)
         self.content_type = parse_attr_value(xmlnode, 'contentType', str)
         self.par = parse_attr_value(xmlnode, 'par', str)
         self.min_bandwidth = parse_attr_value(xmlnode, 'minBandwidth', int)
@@ -564,6 +613,7 @@ class AdaptationSet(RepresentationBase):
         self.min_frame_rate = parse_attr_value(xmlnode, 'minFrameRate', str)
         self.max_frame_rate = parse_attr_value(xmlnode, 'maxFrameRate', str)
         self.segment_alignment = parse_attr_value(xmlnode, 'segmentAlignment', bool)
+        self.selection_priority = parse_attr_value(xmlnode, 'selectionPriority', int)
         self.subsegment_alignment = parse_attr_value(xmlnode, 'subsegmentAlignment', bool)
         self.subsegment_starts_with_sap = parse_attr_value(xmlnode, 'subsegmentStartsWithSAP', int)
         self.bitstream_switching = parse_attr_value(xmlnode, 'bitstreamSwitching', bool)
@@ -585,6 +635,7 @@ class AdaptationSet(RepresentationBase):
         write_attr_value(xmlnode, 'id', self.id)
         write_attr_value(xmlnode, 'group', self.group)
         write_attr_value(xmlnode, 'lang', self.lang)
+        write_attr_value(xmlnode, 'label', self.label)
         write_attr_value(xmlnode, 'contentType', self.content_type)
         write_attr_value(xmlnode, 'par', self.par)
         write_attr_value(xmlnode, 'minBandwidth', self.min_bandwidth)
@@ -596,6 +647,7 @@ class AdaptationSet(RepresentationBase):
         write_attr_value(xmlnode, 'minFrameRate', self.min_frame_rate)
         write_attr_value(xmlnode, 'maxFrameRate', self.max_frame_rate)
         write_attr_value(xmlnode, 'segmentAlignment', self.segment_alignment)
+        write_attr_value(xmlnode, 'selectionPriority', self.selection_priority)
         write_attr_value(xmlnode, 'subsegmentAlignment', self.subsegment_alignment)
         write_attr_value(xmlnode, 'subsegmentStartsWithSAP', self.subsegment_starts_with_sap)
         write_attr_value(xmlnode, 'bitstreamSwitching', self.bitstream_switching)
@@ -688,6 +740,7 @@ class MPEGDASH(XMLNode):
         self.id = None                                        # xs:string
         self.type = None                                      # PresentationType
         self.profiles = ''                                    # xs:string (required)
+        self.cenc = None                                      # xs:string
         self.availability_start_time = None                   # xs:dateTime
         self.availability_end_time = None                     # xs:dateTime
         self.publish_time = None                              # xs:dateTime
@@ -711,6 +764,7 @@ class MPEGDASH(XMLNode):
         self.id = parse_attr_value(xmlnode, 'id', str)
         self.type = parse_attr_value(xmlnode, 'type', str)
         self.profiles = parse_attr_value(xmlnode, 'profiles', str)
+        self.cenc = parse_attr_value(xmlnode, "xmlns:cenc", str)
         self.availability_start_time = parse_attr_value(xmlnode, 'availabilityStartTime', str)
         self.availability_end_time = parse_attr_value(xmlnode, 'availabilityEndTime', str)
         self.publish_time = parse_attr_value(xmlnode, 'publishTime', str)
@@ -734,6 +788,7 @@ class MPEGDASH(XMLNode):
         write_attr_value(xmlnode, 'id', self.id)
         write_attr_value(xmlnode, 'type', self.type)
         write_attr_value(xmlnode, 'profiles', self.profiles)
+        write_attr_value(xmlnode, "xmlns:cenc", self.cenc)
         write_attr_value(xmlnode, 'availabilityStartTime', self.availability_start_time)
         write_attr_value(xmlnode, 'availabilityEndTime', self.availability_end_time)
         write_attr_value(xmlnode, 'publishTime', self.publish_time)
