@@ -1,11 +1,6 @@
+from urllib.request import urlopen
 from xml.dom import minidom
 
-# python3 support
-try:
-    from urllib2 import urlopen
-except ImportError:
-    from urllib.request import urlopen
-
 from mpegdash.nodes import MPEGDASH
 from mpegdash.utils import parse_child_nodes, write_child_node
 from mpegdash.prettyprinter import pretty_print
